Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(608)

Unified Diff: cc/input/input_handler.h

Issue 2471523002: Make touch events uncancelable during fling when they are on the current active scroll layer (Closed)
Patch Set: fling layer Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | cc/trees/layer_tree_host_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/input/input_handler.h
diff --git a/cc/input/input_handler.h b/cc/input/input_handler.h
index d60e9d44c7bcf96a2d4564f9ede5a61b2977b06e..7e6124c0a07297a9461a81bc7950a0e31b9dd13b 100644
--- a/cc/input/input_handler.h
+++ b/cc/input/input_handler.h
@@ -104,6 +104,12 @@ class CC_EXPORT InputHandler {
NON_BUBBLING_GESTURE
};
+ enum class TouchStartEventListenerType {
+ NO_HANDLER,
+ HANDLER,
+ HANDLER_ON_SCROLLING_LAYER
+ };
+
// Binds a client to this handler to receive notifications. Only one client
// can be bound to an InputHandler. The client must live at least until the
// handler calls WillShutdown() on the client.
@@ -187,9 +193,12 @@ class CC_EXPORT InputHandler {
virtual EventListenerProperties GetEventListenerProperties(
EventListenerClass event_class) const = 0;
+ // It returns the type of a touch start event listener at |viewport_point|.
// Whether the page should be given the opportunity to suppress scrolling by
- // consuming touch events that started at |viewport_point|.
- virtual bool DoTouchEventsBlockScrollAt(const gfx::Point& viewport_point) = 0;
+ // consuming touch events that started at |viewport_point|, and whether
+ // |viewport_point| is on the currently scrolling layer.
+ virtual TouchStartEventListenerType EventListenerTypeForTouchStartAt(
+ const gfx::Point& viewport_point) = 0;
// Calling CreateLatencyInfoSwapPromiseMonitor() to get a scoped
// LatencyInfoSwapPromiseMonitor. During the life time of the
« no previous file with comments | « no previous file | cc/trees/layer_tree_host_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698